@@ -74,7 +74,14 @@ impl Widget for SliderCardWidget {
             Msg::Input(input) => {
                 self.update_current(&input.value);
                 self.parse(&input.value);
-                self.send(ctx);
+                let instant_send = ctx
+                    .meta()
+                    .state()
+                    .map(|state| state.spec.instant)
+                    .unwrap_or_default();
+                if instant_send {
+                    self.send(ctx);
+                }
             }
             Msg::Change(other) => {
                 log::error!("Unsupported event for slider: {:?}", other);
@@ -98,7 +105,7 @@ impl Widget for SliderCardWidget {
                             min=state.spec.min.to_string()
                             max=state.spec.max.to_string()
                             step=state.spec.step.to_string()
-                            value={self.temp_value.clone().unwrap_or(state.value).to_string()}
+                            value={self.temp_value.unwrap_or(state.value).to_string()}
                             // I used `callback` instead of `event`, because `ChangeData` in not
                             // cloneable and `Msg` poisoned of it.
                             onmousedown=ctx.callback(|_| Msg::BeginChange)
