@@ -1,7 +1,7 @@
 use crate::cards::render;
 use rill_protocol::io::provider::{EntryId, Path};
-use rrpack_prime::manifest::description::PackFlowDescription;
-use rrpack_prime::manifest::layouts::layout::{Label, LayoutItem, Position, Size};
+use rrpack_basis::manifest::description::PackFlowDescription;
+use rrpack_basis::manifest::layouts::layout::{Label, LayoutItem, Position, Size};
 use std::cmp::{Ord, Ordering};
 use yew::{html, Html, NodeRef};
 
@@ -62,7 +62,7 @@ impl Record {
             "position: absolute; top: {}%; left: {}%; height: {}%; width: {}%;",
             top, left, height, width
         );
-        let inner_html = (record.rule.render)(&record.path);
+        let inner_html = record.rule.render.render(&record.path);
         html! {
             <div style=style ref=record.node_ref.clone()>
                 { inner_html }
@@ -96,7 +96,7 @@ impl Ord for Record {
 
 impl PartialOrd for Record {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 
