@@ -18,8 +18,8 @@ impl Widget for DashboardMenuWidget {
     fn view(&self, _ctx: &Context<Self>) -> Html {
         html! {
             <>
-                <super::PackageSelector />
-                <super::DashboardSelector />
+                <super::TopSelector />
+                <super::TabSelector />
             </>
         }
     }
