@@ -4,18 +4,18 @@ pub use dashboard::Dashboard;
 mod dashboard_menu;
 pub use dashboard_menu::DashboardMenu;
 
-mod dashboard_selector;
-use dashboard_selector::DashboardSelector;
-
 mod group_viewer;
 use group_viewer::GroupViewer;
 
-mod package_selector;
-use package_selector::PackageSelector;
-
 pub mod record;
 
 pub mod state;
 
 mod loader;
 pub use loader::Loader;
+
+mod top_selector;
+use top_selector::TopSelector;
+
+mod tab_selector;
+use tab_selector::TabSelector;
