@@ -1,7 +1,7 @@
 use crate::cards::render;
 use rate_ui::packages::talent::flexlayout::Item;
 use rill_protocol::io::provider::{EntryId, Path};
-use rrpack_prime::manifest::description::PackFlowDescription;
+use rrpack_basis::manifest::description::PackFlowDescription;
 use std::cmp::{Ord, Ordering};
 use yew::{html, Html, NodeRef};
 
@@ -9,14 +9,22 @@ impl Record {
     pub fn render(item: Option<&Item<Self>>) -> Html {
         if let Some(item) = item {
             let record = &item.record;
-            let inner_html = (record.rule.render)(&record.path);
+            let inner_html = record.rule.render.render(&record.path);
             let style = format!("order: {};", item.order,);
-            let size = format!(
-                " width: {}px; height: {}px;",
-                record.rule.size.width, record.rule.size.height,
-            );
+            let grow;
+            let size;
+            if record.rule.grow {
+                size = format!("height: {}px;", record.rule.size.height,);
+                grow = "flex-grow-1";
+            } else {
+                size = format!(
+                    "width: {}px; height: {}px;",
+                    record.rule.size.width, record.rule.size.height,
+                );
+                grow = "";
+            }
             html! {
-                <div class="pe-3 pb-3 d-flex" style=style ref=record.node_ref.clone()>
+                <div class=format!("pe-3 pb-3 d-flex {}", grow) style=style ref=record.node_ref.clone()>
                     <div class="bg-light shadow-sm w-100 d-flex flex-column">
                         <div class="pt-3 text-center caption">{ &record.name }</div>
                         <div style=size>
@@ -64,7 +72,7 @@ impl Ord for Record {
 
 impl PartialOrd for Record {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 
